# Changelog

## 1.0.0-beta.4 (2026-01-16)

Full Changelog: [v1.0.0-beta.3...v1.0.0-beta.4](https://github.com/run-llama/llama-cloud-py/compare/v1.0.0-beta.3...v1.0.0-beta.4)

### Features

* **api:** api update ([4a23421](https://github.com/run-llama/llama-cloud-py/commit/4a23421a36a23a765afffa3526ace922191c1300))
* **api:** Consolidate more pagination, rename functions ([0b099f3](https://github.com/run-llama/llama-cloud-py/commit/0b099f3f9b691b9045935e8dc0bd51b88f25eaf6))
* **api:** update via SDK Studio ([318a8e9](https://github.com/run-llama/llama-cloud-py/commit/318a8e976b89e3f44b23ef8396d6faaf5bc243e3))
* **api:** update via SDK Studio ([5dd21ce](https://github.com/run-llama/llama-cloud-py/commit/5dd21ce6aedf524101c2052f072f3593f11cd9a7))
* **api:** update via SDK Studio ([18385da](https://github.com/run-llama/llama-cloud-py/commit/18385daf200044012e2ae466807f9a33f660a498))
* **api:** update via SDK Studio ([48879bc](https://github.com/run-llama/llama-cloud-py/commit/48879bc4ece770f5e8506ee00eee3f2093a4932b))
* **api:** update via SDK Studio ([bd46c8b](https://github.com/run-llama/llama-cloud-py/commit/bd46c8b14a66e950bf291e96ca8b4a06dd1c731d))

## 1.0.0-beta.3 (2026-01-14)

Full Changelog: [v0.20.0...v1.0.0-beta.3](https://github.com/run-llama/llama-cloud-py/compare/v0.20.0...v1.0.0-beta.3)

### Features

* **api:** manual updates ([c23da58](https://github.com/run-llama/llama-cloud-py/commit/c23da58fc7096b490c1083d98654cd9bc3db36c1))
* **client:** add support for binary request streaming ([d6cbf95](https://github.com/run-llama/llama-cloud-py/commit/d6cbf954f2c8b7a29a44b8929acc7c76501720fe))


### Chores

* **internal:** codegen related update ([95d0c9a](https://github.com/run-llama/llama-cloud-py/commit/95d0c9abbc779d791fa72acc6ecc53808cacbec3))
* update SDK settings ([0a091c1](https://github.com/run-llama/llama-cloud-py/commit/0a091c12d0b88332786a1e2ba538b027ba41e6aa))

## 0.20.0 (2026-01-14)

Full Changelog: [v0.19.1...v0.20.0](https://github.com/run-llama/llama-cloud-py/compare/v0.19.1...v0.20.0)

### Features

* **api:** api update ([725a04e](https://github.com/run-llama/llama-cloud-py/commit/725a04ec0adc9360b572027a8eaf95e9246e9639))
* **api:** parse v2alpha1 -&gt; v2 ([83fa7c4](https://github.com/run-llama/llama-cloud-py/commit/83fa7c47a1681a4284ca06d8e61a67540c15d4c6))
* **api:** Removing false upload_file endpoint ([d05898c](https://github.com/run-llama/llama-cloud-py/commit/d05898c21995f17a5bebffa9d53e3140b6bb0d2b))
* **api:** Removing false upload_file endpoint ([ff905f1](https://github.com/run-llama/llama-cloud-py/commit/ff905f17f3d7bf0f3db2639db54652f3598a10f8))


### Chores

* configure new SDK language ([5249848](https://github.com/run-llama/llama-cloud-py/commit/5249848c58c9420bfebc9157969627d368e77bb7))

## 0.19.1 (2026-01-10)

Full Changelog: [v0.19.0...v0.19.1](https://github.com/run-llama/llama-cloud-py/compare/v0.19.0...v0.19.1)

## 0.19.0 (2026-01-10)

Full Changelog: [v0.18.0...v0.19.0](https://github.com/run-llama/llama-cloud-py/compare/v0.18.0...v0.19.0)

### Features

* **api:** api update ([028190e](https://github.com/run-llama/llama-cloud-py/commit/028190ed0b7c0f5e4eee8f913cb13f3745ad3ecc))
* **api:** manual updates ([3616730](https://github.com/run-llama/llama-cloud-py/commit/36167303b3980a45b56039d959435a35c6d866c8))

## 0.18.0 (2026-01-08)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/run-llama/llama-cloud-py/compare/v0.17.0...v0.18.0)

### Features

* **api:** add list commands to pipeline file images ([e9ac62e](https://github.com/run-llama/llama-cloud-py/commit/e9ac62ecfee8b9020e169010cc910989dc491c78))

## 0.17.0 (2026-01-06)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/run-llama/llama-cloud-py/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([b4a17d8](https://github.com/run-llama/llama-cloud-py/commit/b4a17d84ae557c68ea5186481b1e2bf0bade435a))

## 0.16.0 (2026-01-06)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/run-llama/llama-cloud-py/compare/v0.15.0...v0.16.0)

### Features

* **api:** add back pipeline files ([ca81b27](https://github.com/run-llama/llama-cloud-py/commit/ca81b27d04ee0bdeb0484d6638509197a6f9cb1b))
* **api:** add pipelines image utils ([dd26528](https://github.com/run-llama/llama-cloud-py/commit/dd26528422b7053e132470f4498fac26d4f6e168))
* **api:** api update ([31d2071](https://github.com/run-llama/llama-cloud-py/commit/31d2071597fe67d2b397bc441e354451de60bc95))
* **api:** api update ([064c1ad](https://github.com/run-llama/llama-cloud-py/commit/064c1adeb43804de1e1acdc00b4fcd187f7ee2ce))
* **api:** Fix readme ([54cb781](https://github.com/run-llama/llama-cloud-py/commit/54cb7817269c3751562f05e550b5691eb8a74276))
* **api:** swap in files v2 support ([fbd41a4](https://github.com/run-llama/llama-cloud-py/commit/fbd41a4abae1f02b39f61d576befcad9c903b2b6))
* **api:** typo ([3e8bce8](https://github.com/run-llama/llama-cloud-py/commit/3e8bce86f76f09bd708cc246247ad60b1976fb56))

## 0.15.0 (2026-01-06)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/run-llama/llama-cloud-py/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([1c43170](https://github.com/run-llama/llama-cloud-py/commit/1c43170b98fbad88a24295db44527cf06f4d2c2a))
* **api:** api update ([dec9b8b](https://github.com/run-llama/llama-cloud-py/commit/dec9b8b1b34f990821f7d967878dc362bfc5c19e))


### Chores

* **internal:** codegen related update ([fb629e4](https://github.com/run-llama/llama-cloud-py/commit/fb629e4cf0dacd3a708cc4705ccc9e0c3fd542be))

## 0.14.0 (2025-12-23)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/run-llama/llama-cloud-py/compare/v0.13.0...v0.14.0)

### Features

* **api:** api update ([f51c7dc](https://github.com/run-llama/llama-cloud-py/commit/f51c7dcd316db757103b8429a372bde2d4aaa0ea))
* **api:** api update ([ff5295d](https://github.com/run-llama/llama-cloud-py/commit/ff5295ddccab0cf23ce854c9e393ced2f114f8db))
* **api:** api update ([5335d08](https://github.com/run-llama/llama-cloud-py/commit/5335d085a7cded66214f8d74ba1ff9f2fadc490f))
* **api:** api update ([68dabd1](https://github.com/run-llama/llama-cloud-py/commit/68dabd199971a8cd1fa43d781725ef733be466d5))
* **api:** api update ([20cbc0d](https://github.com/run-llama/llama-cloud-py/commit/20cbc0d9d57a06cc448e7cc6f7d9cf9e72a5ec38))
* **api:** api update ([5be72ef](https://github.com/run-llama/llama-cloud-py/commit/5be72ef51bb7be7ad44ac1085ca24885bf7dbc81))
* **api:** parse v2 updates ([6d8e09c](https://github.com/run-llama/llama-cloud-py/commit/6d8e09cb5e729bcf6095ba3a99f7591059fbd0e3))
* **api:** swap in parse v2 support ([0134a13](https://github.com/run-llama/llama-cloud-py/commit/0134a13d5c013fcce6943105098587bb60828439))
* **api:** update readme ([4d21124](https://github.com/run-llama/llama-cloud-py/commit/4d21124abf414ffbbca5ed36dc39074d4109ed8a))
* **api:** use repeat query params with and char ([054c5ac](https://github.com/run-llama/llama-cloud-py/commit/054c5ac34d65b0aa64082ac7d3983a63ff789d65))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([a8a44f6](https://github.com/run-llama/llama-cloud-py/commit/a8a44f6b6a3cf622d807100517b325b94875f9ed))
* use async_to_httpx_files in patch method ([f137ed7](https://github.com/run-llama/llama-cloud-py/commit/f137ed7ca66be65fb5917ac0739a6243b549e255))


### Chores

* add missing docstrings ([f5b5cf9](https://github.com/run-llama/llama-cloud-py/commit/f5b5cf90f95785bc59332ffec6a1d8bd4040b24d))
* **internal:** add `--fix` argument to lint script ([4a5d9d0](https://github.com/run-llama/llama-cloud-py/commit/4a5d9d0f73c423828c3cc6a46cc0b09067776e43))
* **internal:** add missing files argument to base client ([cfd8fc8](https://github.com/run-llama/llama-cloud-py/commit/cfd8fc8da24d63ed6669c17bda54e2e081bdfa17))
* speedup initial import ([98e32fc](https://github.com/run-llama/llama-cloud-py/commit/98e32fcb35dbc9762ba8b57658aefb06535a2ffc))

## 0.13.0 (2025-12-04)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/run-llama/llama-cloud-py/compare/v0.12.0...v0.13.0)

### Features

* **api:** add list page screenshots/figures ([e4c618c](https://github.com/run-llama/llama-cloud-py/commit/e4c618c4046da38d0d4234f934c6a80f782839ce))

## 0.12.0 (2025-12-03)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/run-llama/llama-cloud-py/compare/v0.11.0...v0.12.0)

### Features

* **api:** add split ([2219e71](https://github.com/run-llama/llama-cloud-py/commit/2219e712b4ab3a196b04e425a73b7e2af52bed43))


### Chores

* **docs:** use environment variables for authentication in code snippets ([f054d44](https://github.com/run-llama/llama-cloud-py/commit/f054d44d903f850e2503029f2399f4cee10606ae))
* update lockfile ([3f8db4e](https://github.com/run-llama/llama-cloud-py/commit/3f8db4ea90ea3c268c3f59dd9cb2da7166e61f50))

## 0.11.0 (2025-12-03)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/run-llama/llama-cloud-py/compare/v0.10.0...v0.11.0)

### Features

* **api:** add some missing endpoints ([f5dbc21](https://github.com/run-llama/llama-cloud-py/commit/f5dbc213944ce8745026ca7beb65c407551b8a75))
* **api:** api update ([609d9be](https://github.com/run-llama/llama-cloud-py/commit/609d9be78a50a9dc982b251ab5a78540d2c183a6))
* **api:** api update ([293983f](https://github.com/run-llama/llama-cloud-py/commit/293983f07682026038d2a36c4e8cf51d284cc597))

## 0.10.0 (2025-12-01)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/run-llama/llama-cloud-py/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([981b2ea](https://github.com/run-llama/llama-cloud-py/commit/981b2ea0a185083d61519b1231f0a7d482e48054))
* **api:** fix readme example ([b615fbf](https://github.com/run-llama/llama-cloud-py/commit/b615fbf2b32e4dbf9e3eb162f25c145451cadc7a))

## 0.9.0 (2025-12-01)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/run-llama/llama-cloud-py/compare/v0.8.0...v0.9.0)

### Features

* **api:** add pipeline.retrieve method ([cd02c34](https://github.com/run-llama/llama-cloud-py/commit/cd02c34bd8fc89c08a1baf05432fccef2bb2aee7))
* **api:** api update ([c86b1a4](https://github.com/run-llama/llama-cloud-py/commit/c86b1a48c483384179e8fa9aff1adecac8c11149))

## 0.8.0 (2025-11-28)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/run-llama/llama-cloud-py/compare/v0.7.0...v0.8.0)

### Features

* **api:** add get page figure/screenshot methods ([388d86e](https://github.com/run-llama/llama-cloud-py/commit/388d86e0d6a749632ef2deb00ee1917b00df9aba))

## 0.7.0 (2025-11-28)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/run-llama/llama-cloud-py/compare/v0.6.0...v0.7.0)

### Features

* **api:** add back projects list/get ([b6b41a1](https://github.com/run-llama/llama-cloud-py/commit/b6b41a1d0289452e64c3440d9c414854155d82dd))
* **api:** api update ([fdd82e0](https://github.com/run-llama/llama-cloud-py/commit/fdd82e082bdfc3b237a815dc9255b469fdb19dfe))


### Bug Fixes

* ensure streams are always closed ([7f1be5b](https://github.com/run-llama/llama-cloud-py/commit/7f1be5b2c486da8f17dd2315eceb9d1ea465172f))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([9a79655](https://github.com/run-llama/llama-cloud-py/commit/9a796552cca42dcfc3b58a15afe350fed4eb7c83))

## 0.6.0 (2025-11-27)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/run-llama/llama-cloud-py/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([652a7a8](https://github.com/run-llama/llama-cloud-py/commit/652a7a8ad5ada51a312c965d04e7726895f44f8c))

## 0.5.0 (2025-11-27)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/run-llama/llama-cloud-py/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([0c5e51f](https://github.com/run-llama/llama-cloud-py/commit/0c5e51fe3ea77ac4b2f4776dee77be261806eed8))
* **api:** manual updates ([2d593a1](https://github.com/run-llama/llama-cloud-py/commit/2d593a16432cbf54bad7ea74d80c095888204d7a))

## 0.4.0 (2025-11-26)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/run-llama/llama-cloud-py/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([1c11d9d](https://github.com/run-llama/llama-cloud-py/commit/1c11d9d8763217a43e660950b8646b4e649a96be))
* **api:** fix api key name ([85e9cb3](https://github.com/run-llama/llama-cloud-py/commit/85e9cb3c94000b7c639bdb5fcfe7b263bf1acc83))
* **api:** manual updates ([a03d412](https://github.com/run-llama/llama-cloud-py/commit/a03d41232fe84af09fdfcdb30d0ac5f16962595a))
* **api:** update extract API endpoints ([7c30619](https://github.com/run-llama/llama-cloud-py/commit/7c306198d06dd508c4f2a0499692cd74c6266ae4))

## 0.3.0 (2025-11-23)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/run-llama/llama-cloud-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** Add missing api endpoints ([c8e9c07](https://github.com/run-llama/llama-cloud-py/commit/c8e9c0775a1fa6409e6fab5429d9fbaffed0526b))
* **api:** api update ([c4dac52](https://github.com/run-llama/llama-cloud-py/commit/c4dac5205f77ce7cf256a27b3c86d8a2b49828e7))
* **api:** api update ([e1ff8b1](https://github.com/run-llama/llama-cloud-py/commit/e1ff8b12c0759cd0750f68c84bd5a6a3730e95f1))
* **api:** api update ([01f2af5](https://github.com/run-llama/llama-cloud-py/commit/01f2af5dbe77c6203c80368f239b0e9e14d041a6))
* **api:** manual updates ([e6efd22](https://github.com/run-llama/llama-cloud-py/commit/e6efd22383c2c3a4b26e50534be25683fdfcf246))
* **api:** manual updates ([2a52d8c](https://github.com/run-llama/llama-cloud-py/commit/2a52d8c87e940d558198cf434f0400e97a8af144))
* **api:** manual updates ([088fbcc](https://github.com/run-llama/llama-cloud-py/commit/088fbccd80a975ea05ca3d5ff44a77497fdb52f2))
* **api:** manual updates ([70248a5](https://github.com/run-llama/llama-cloud-py/commit/70248a5c9198c455c3a704cb24790da8524af07b))
* **api:** manual updates ([ffc9c2c](https://github.com/run-llama/llama-cloud-py/commit/ffc9c2cfa2dde27f05507fd1922c2ea1787f3d6c))
* **api:** manual updates ([571deab](https://github.com/run-llama/llama-cloud-py/commit/571deab5d900476ac4c1dbb0bf71f11ec381ba1f))
* **api:** manual updates ([8f19b18](https://github.com/run-llama/llama-cloud-py/commit/8f19b18152ddb24bbbc7e467d6ca1e6e78335853))
* **api:** manual updates ([8794d62](https://github.com/run-llama/llama-cloud-py/commit/8794d62ca0dc827f2f5cd00f42fe6272c34cd442))
* **api:** manual updates ([6f90a08](https://github.com/run-llama/llama-cloud-py/commit/6f90a0856da964070c061225c189b14bb635634f))
* **api:** manual updates ([2f47fa9](https://github.com/run-llama/llama-cloud-py/commit/2f47fa9713ea35bcb02bc80d9e36415a97cf7a58))
* **api:** manual updates ([82bcafa](https://github.com/run-llama/llama-cloud-py/commit/82bcafa88fbcedfaea163e5b95d3da50b878c011))
* **api:** manual updates ([abed126](https://github.com/run-llama/llama-cloud-py/commit/abed1261c6dbc0cb1a8fc07191516c34e947ea72))
* **api:** manual updates ([d4c400b](https://github.com/run-llama/llama-cloud-py/commit/d4c400bfd30e982b6cbccee7f5dbac6215bd5da9))
* **api:** remove some agent items ([8282fa2](https://github.com/run-llama/llama-cloud-py/commit/8282fa2a7d37ae04d8d68091eb99ab124ff1e425))


### Chores

* add Python 3.14 classifier and testing ([5c8f944](https://github.com/run-llama/llama-cloud-py/commit/5c8f944ce59e39565f5fcba65fb65d33e9f6d732))

## 0.2.0 (2025-11-19)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/run-llama/llama-cloud-py/compare/v0.1.1...v0.2.0)

### Features

* **api:** api update ([02e9e08](https://github.com/run-llama/llama-cloud-py/commit/02e9e088adfe7842c3a098e816aa6930ae156e86))


### Bug Fixes

* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([9784558](https://github.com/run-llama/llama-cloud-py/commit/97845584d969cf89fb7b28f4d5acea26055c0e50))

## 0.1.1 (2025-11-11)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/run-llama/llama-cloud-py/compare/v0.1.0...v0.1.1)

### Bug Fixes

* compat with Python 3.14 ([198061d](https://github.com/run-llama/llama-cloud-py/commit/198061d9a14a632331aee4300e2c4fe3a39e10d8))


### Chores

* **package:** drop Python 3.8 support ([dba8e3a](https://github.com/run-llama/llama-cloud-py/commit/dba8e3a953a3f5d29a5357fd7c46babfd2e9b7cb))

## 0.1.0 (2025-11-07)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/run-llama/llama-cloud-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** add pagination config ([a09a6bf](https://github.com/run-llama/llama-cloud-py/commit/a09a6bf431ddd321b14a6c5574117690f7cbae00))
* **api:** api update ([5e2aade](https://github.com/run-llama/llama-cloud-py/commit/5e2aade9aefa461b215f37fe60239cea20c98cf8))
* **api:** api update ([64c9670](https://github.com/run-llama/llama-cloud-py/commit/64c9670fcf95169273929d13fc46c2b11efd62b5))
* **api:** api update ([34f9ead](https://github.com/run-llama/llama-cloud-py/commit/34f9ead6480e2bb8176e73b92e21bcac2c4998df))
* **api:** api update ([3b2842f](https://github.com/run-llama/llama-cloud-py/commit/3b2842f681a011d56ccf7b7eb9d0b0fa5938bbae))
* **api:** api update ([4e3731c](https://github.com/run-llama/llama-cloud-py/commit/4e3731c85afd4efaa2492b36ff72ced402a1df2b))
* **api:** api update ([aad8635](https://github.com/run-llama/llama-cloud-py/commit/aad8635110d562f64e08e84d2dc3552066b174be))
* **api:** clean up schemas ([0e93369](https://github.com/run-llama/llama-cloud-py/commit/0e9336946b3ef953ed1e851621a5bba393971ef0))
* **api:** fix pagination example in readme ([7bdd2b6](https://github.com/run-llama/llama-cloud-py/commit/7bdd2b66e7ece7923c0a3341d32ecfe830ad41eb))
* **api:** manual updates ([dd6fde5](https://github.com/run-llama/llama-cloud-py/commit/dd6fde5feb15a8a47f5ef22342dbe1e5b251a3a0))
* **api:** manual updates ([a4fb399](https://github.com/run-llama/llama-cloud-py/commit/a4fb39918251947b112db1159c5cd4fc954d3751))
* **api:** manual updates ([1015a46](https://github.com/run-llama/llama-cloud-py/commit/1015a4645225859fd76d303e72c5e32262bdec3d))
* **api:** manual updates ([9aaa486](https://github.com/run-llama/llama-cloud-py/commit/9aaa486baa8071d1bced680c458a522368352d52))
* **api:** more cleanup ([daee74d](https://github.com/run-llama/llama-cloud-py/commit/daee74d609630bf1b4690c01d15119f99c96ec8e))
* **api:** update readme ([bf4d489](https://github.com/run-llama/llama-cloud-py/commit/bf4d489a8fd70c48923311e1cdf92716c9cfdfb8))


### Bug Fixes

* **client:** close streams without requiring full consumption ([243dea9](https://github.com/run-llama/llama-cloud-py/commit/243dea98df257f78ccf52a3baea18e1021ed4781))


### Chores

* configure new SDK language ([21510df](https://github.com/run-llama/llama-cloud-py/commit/21510df5cbe886f1fcb5e9e9d542bf7369c25ce9))
* **internal/tests:** avoid race condition with implicit client cleanup ([cc38e89](https://github.com/run-llama/llama-cloud-py/commit/cc38e89f51106fee9df9d4b3db1bed3e3c0145d2))
* **internal:** grammar fix (it's -&gt; its) ([f0c3628](https://github.com/run-llama/llama-cloud-py/commit/f0c36285f6ea54ffeb7231bc6cd55b89f4272f3b))
